@@ -25,9 +25,9 @@ struct DefaultStyle <: StructStyle end
 include("macros.jl")
 
 """
-  StructUtils.dictlike(x) -> Bool
-  StructUtils.dictlike(::StructStyle, x) -> Bool
-  StructUtils.dictlike(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.dictlike(x) -> Bool
+    StructUtils.dictlike(::StructStyle, x) -> Bool
+    StructUtils.dictlike(::StructStyle, ::Type{T}) -> Bool
 
 Returns `true` if `x` or type `T` is dictionary-like, `false` otherwise.
 When `StructUtils.make(T, source)` is called, if `dictlike(T)` is `true`,
@@ -43,9 +43,9 @@ dictlike(::Type{<:AbstractVector{<:Pair}}) = true
 dictlike(@nospecialize(T)) = false
 
 """
-  StructUtils.noarg(x) -> Bool
-  StructUtils.noarg(::StructStyle, x) -> Bool
-  StructUtils.noarg(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.noarg(x) -> Bool
+    StructUtils.noarg(::StructStyle, x) -> Bool
+    StructUtils.noarg(::StructStyle, ::Type{T}) -> Bool
 
 Signals that `x` or type `T` is a mutable type that can be constructed by calling an empty
 constructor, like `t = T()`. Automatically overloaded when structs use the
@@ -59,9 +59,9 @@ noarg(::StructStyle, T::Type) = noarg(T)
 noarg(@nospecialize(T)) = false
 
 """
-  StructUtils.kwarg(x) -> Bool
-  StructUtils.kwarg(::StructStyle, x) -> Bool
-  StructUtils.kwarg(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.kwarg(x) -> Bool
+    StructUtils.kwarg(::StructStyle, x) -> Bool
+    StructUtils.kwarg(::StructStyle, ::Type{T}) -> Bool
 
 Signals that `x` or type `T` can be constructed by passing struct fields as keyword arguments
 to the constructor, like `t = T(field1=a, field2=b, ...)`. Automatically overloaded
@@ -193,9 +193,9 @@ _valtype(d) = valtype(d)
 _valtype(::AbstractVector{Pair{A,B}}) where {A,B} = B
 
 """
-  StructUtils.arraylike(x) -> Bool
-  StructUtils.arraylike(::StructStyle, x) -> Bool
-  StructUtils.arraylike(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.arraylike(x) -> Bool
+    StructUtils.arraylike(::StructStyle, x) -> Bool
+    StructUtils.arraylike(::StructStyle, ::Type{T}) -> Bool
 
 Returns `true` if `x` or type `T` is array-like, `false` otherwise. This function is
 called by `StructUtils.make` to determine if `T` is array-like. The default
@@ -218,9 +218,9 @@ arraylike(::Type{<:Core.SimpleVector}) = true
 arraylike(@nospecialize(T)) = false
 
 """
-  StructUtils.structlike(x) -> Bool
-  StructUtils.structlike(::StructStyle, x) -> Bool
-  StructUtils.structlike(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.structlike(x) -> Bool
+    StructUtils.structlike(::StructStyle, x) -> Bool
+    StructUtils.structlike(::StructStyle, ::Type{T}) -> Bool
 
 Returns `true` if `x` or type `T` is struct-like, `false` otherwise. This function is
 called by `StructUtils.make` to determine if `T` is struct-like. The default
@@ -250,12 +250,15 @@ structlike(::Type{Nothing}) = false
 structlike(::Type{Missing}) = false
 structlike(::Type{UUID}) = false
 structlike(::Type{VersionNumber}) = false
-structlike(@nospecialize(T)) = isstructtype(T) && !Base.issingletontype(T)
+structlike(::Type{MIME}) = false
+structlike(::Type{<:NamedTuple}) = true
+structlike(@nospecialize(x)) = structlike(typeof(x))
+structlike(@nospecialize(T::Type)) = isstructtype(T) && !Base.issingletontype(T)
 
 """
-  StructUtils.nulllike(x) -> Bool
-  StructUtils.nulllike(::StructStyle, x) -> Bool
-  StructUtils.nulllike(::StructStyle, ::Type{T}) -> Bool
+    StructUtils.nulllike(x) -> Bool
+    StructUtils.nulllike(::StructStyle, x) -> Bool
+    StructUtils.nulllike(::StructStyle, ::Type{T}) -> Bool
 
 Returns `true` if `x` or type `T` is null-like, `false` otherwise. This function is
 mainly used in the `make!` implementation to determine if a
@@ -268,8 +271,8 @@ nulllike(::StructStyle, T::Type) = nulllike(T)
 nulllike(@nospecialize(T)) = T === Missing || T === Nothing
 
 """
-  StructUtils.lower(x) -> x
-  StructUtils.lower(::StructStyle, x) -> x
+    StructUtils.lower(x) -> x
+    StructUtils.lower(::StructStyle, x) -> x
 
 Domain value transformation function. This function is called by
 `StructUtils.applyeach` on each value in the `source` object before
@@ -294,8 +297,8 @@ function lower(st::StructStyle, x, tags)
 end
 
 """
-  StructUtils.lowerkey(x) -> x
-  StructUtils.lowerkey(style::StructUtils.StructStyle, x) -> x
+    StructUtils.lowerkey(x) -> x
+    StructUtils.lowerkey(style::StructUtils.StructStyle, x) -> x
 
 Allows customizing how a value is lowered when used specifically as a key.
 By default, calls [`StructUtils.lower`](@ref). Called from [`StructUtils.applyeach`](@ref)
@@ -324,13 +327,13 @@ lowerkey(::StructStyle, x) = lowerkey(x)
 lowerkey(x) = x
 
 """
-  StructUtils.lift(::Type{T}, x) -> T
-  StructUtils.lift(::StructStyle, ::Type{T}, x) -> Tuple{T, Any}
+    StructUtils.lift(::Type{T}, x) -> T
+    StructUtils.lift(::StructStyle, ::Type{T}, x) -> Tuple{T, Any}
 
 Lifts a value `x` to a type `T`. This function is called by `StructUtils.make`
 to lift unit/atom values to the appropriate type. The default implementation is
 the identity function for most types, but it also includes special cases
-for `Symbol`, `Char`, `UUID`, `VersionNumber`, `Regex`, and `TimeType` types to be
+for `Symbol`, `Char`, `UUID`, `VersionNumber`, `MIME`, `Regex`, and `TimeType` types to be
 constructed from strings.
 Allows transforming a "domain value" that may be some primitive representation
 into a more complex Julia type.
@@ -350,6 +353,7 @@ lift(::Type{>:Union{Missing,Nothing}}, ::Missing) = missing
 lift(::Type{Char}, x::AbstractString) = length(x) == 1 ? x[1] : throw(ArgumentError("expected single character, got $x"))
 lift(::Type{UUID}, x::AbstractString) = UUID(x)
 lift(::Type{VersionNumber}, x::AbstractString) = VersionNumber(x)
+lift(::Type{MIME}, x::AbstractString) = MIME(x)
 lift(::Type{Regex}, x::AbstractString) = Regex(x)
 lift(::Type{T}, x::AbstractString) where {T<:Dates.TimeType} = T(x)
 
@@ -385,8 +389,8 @@ function lift(st::StructStyle, ::Type{T}, x, tags) where {T}
 end
 
 """
-  StructUtils.liftkey(::Type{T}, x) -> x
-  StructUtils.liftkey(style::StructStyle, ::Type{T}, x) -> x
+    StructUtils.liftkey(::Type{T}, x) -> x
+    StructUtils.liftkey(style::StructStyle, ::Type{T}, x) -> x
 
 Allows customizing how a key is lifted before being passed to [`addkeyval!`](@ref)
 in `dictlike` construction.
@@ -499,6 +503,13 @@ function applyeach(st::StructStyle, f, x::AbstractVector{Pair{K,V}}) where {K,V}
     return defaultstate(st)
 end
 
+# special-case Pair to act like key-value object
+function applyeach(st::StructStyle, f, x::Pair)
+    ret = f(lowerkey(st, x.first), lower(st, x.second))
+    ret isa EarlyReturn && return ret
+    return defaultstate(st)
+end
+
 # appropriate definition for iterables that
 # can't have #undef values
 function applyeach(st::StructStyle, f, x::Union{AbstractSet,Base.Generator,Core.SimpleVector})
@@ -588,6 +599,7 @@ keyeq(a::Symbol, b::String) = a === Symbol(b)
 keyeq(a::String, b::Symbol) = Symbol(a) == b
 keyeq(a, b::String) = string(a) == b
 keyeq(a::AbstractString, b::String) = String(a) == b
+keyeq(a, b::Tuple) = any(keyeq(a), b)
 keyeq(a, b) = isequal(a, b)
 keyeq(x) = y -> keyeq(x, y)
 
@@ -915,7 +927,7 @@ function findfield(::Type{T}, k, v, f) where {T}
             fn = f.fsyms[i]
             ftags = fieldtags(f.style, T, fn)
             field = get(ftags, :name, fn)
-            if k == field
+            if keyeq(k, field) || keyeq(k, fn)
                 symval, symst = make(f.style, fieldtype(T, i), v, ftags)
                 setval!(f.vals, symval, i)
                 return EarlyReturn(symst)
@@ -1002,7 +1014,7 @@ end
 @doc (@doc make) make!
 
 """
-  StructUtils.reset!(x::T)
+    StructUtils.reset!(x::T)
 
 If `T` was defined with default values via `@defaults`, `@tags`, `@kwarg`, or `@noarg`,
 `reset!` will reset the fields of `x` to their default values.
